==> haskell-invariant-0.6.3-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-invariant.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 invariant
version:              0.6.3
visibility:           public
id:                   invariant-0.6.3-GzStJtunzPbbkBM9gaqtT
key:                  invariant-0.6.3-GzStJtunzPbbkBM9gaqtT
license:              BSD-2-Clause
maintainer:
    Nicolas Frisby <nicolas.frisby@gmail.com>,
    Ryan Scott <ryan.gl.scott@gmail.com>

author:               Nicolas Frisby <nicolas.frisby@gmail.com>
homepage:             https://github.com/nfrisby/invariant-functors
synopsis:             Haskell98 invariant functors
description:
    Haskell98 invariant functors (also known as exponential functors).

    For more information, see Edward Kmett'\''s article \"Rotten Bananas\":

    <http://comonad.com/reader/2008/rotten-bananas/>

category:             Control, Data
abi:                  9c87cde88e55238f7a50c8a2cfaaa2a4
exposed:              True
exposed-modules:      Data.Functor.Invariant Data.Functor.Invariant.TH
hidden-modules:       Data.Functor.Invariant.TH.Internal Paths_invariant
import-dirs:          /usr/lib/ghc-9.2.8/site-local/invariant-0.6.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/invariant-0.6.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-invariant
hs-libraries:         HSinvariant-0.6.3-GzStJtunzPbbkBM9gaqtT
depends:
    StateVar-1.2.2-4TJ8CI5wrC5B2qk02v8ZQ3 array-0.5.4.0 base-4.16.4.0
    bifunctors-5.6-C3krR03Vy34Eh0jnv6kpRk
    comonad-5.0.8-KyyLY8sZRYu3prGxjDqPYp containers-0.6.5.1
    contravariant-1.5.5-6oWUjmJNxDBFhugVD5s9dq ghc-prim-0.8.0
    profunctors-5.6.2-GpDaCOOY8ar8rCckMV8A0H stm-2.5.0.2
    tagged-0.8.8-404YCiJ2agdDxJGZ4AybXg template-haskell-2.18.0.0
    th-abstraction-0.4.5.0-FQrzhXbdvQX3Z0wTw3euNu transformers-0.5.6.2
    transformers-compat-0.7.2-9ApmiRwA3hS7UuQpOomcS
    unordered-containers-0.2.20-3nVNqHdmWG59aZRDnxmFox

haddock-interfaces:   /usr/share/doc/haskell-invariant/html/invariant.haddock
haddock-html:         /usr/share/doc/haskell-invariant/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-invariant-0.6.3-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-invariant.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 invariant
version:              0.6.3
visibility:           public
id:                   invariant-0.6.3-9oCpdc8eysk11gKjaQoDoe
key:                  invariant-0.6.3-9oCpdc8eysk11gKjaQoDoe
license:              BSD-2-Clause
maintainer:
    Nicolas Frisby <nicolas.frisby@gmail.com>,
    Ryan Scott <ryan.gl.scott@gmail.com>

author:               Nicolas Frisby <nicolas.frisby@gmail.com>
homepage:             https://github.com/nfrisby/invariant-functors
synopsis:             Haskell98 invariant functors
description:
    Haskell98 invariant functors (also known as exponential functors).

    For more information, see Edward Kmett'\''s article \"Rotten Bananas\":

    <http://comonad.com/reader/2008/rotten-bananas/>

category:             Control, Data
abi:                  313bd761233c9287dbf8f3e90d02979b
exposed:              True
exposed-modules:      Data.Functor.Invariant Data.Functor.Invariant.TH
hidden-modules:       Data.Functor.Invariant.TH.Internal Paths_invariant
import-dirs:          /usr/lib/ghc-9.2.8/site-local/invariant-0.6.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/invariant-0.6.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-invariant
hs-libraries:         HSinvariant-0.6.3-9oCpdc8eysk11gKjaQoDoe
depends:
    StateVar-1.2.2-4TJ8CI5wrC5B2qk02v8ZQ3 array-0.5.4.0 base-4.16.4.0
    bifunctors-5.6-5TPQLiiWq6eCzHRlkDKGL5
    comonad-5.0.8-2MGULbA20KUKXAgMD7ZS7 containers-0.6.5.1
    contravariant-1.5.5-6oWUjmJNxDBFhugVD5s9dq ghc-prim-0.8.0
    profunctors-5.6.2-6LyR8uu9Msg2PY57A7zF4v stm-2.5.0.2
    tagged-0.8.8-404YCiJ2agdDxJGZ4AybXg template-haskell-2.18.0.0
    th-abstraction-0.4.5.0-FQrzhXbdvQX3Z0wTw3euNu transformers-0.5.6.2
    transformers-compat-0.7.2-9ApmiRwA3hS7UuQpOomcS
    unordered-containers-0.2.20-Hx67rce3cSdLKcnqodh5s4

haddock-interfaces:   /usr/share/doc/haskell-invariant/html/invariant.haddock
haddock-html:         /usr/share/doc/haskell-invariant/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
